==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1PodAffinityTermFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1PodAffinityTermFluent<A extends V1PodAffinityTermFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildLabelSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getLabelSelector();
    public V1LabelSelector buildLabelSelector();
    public A withLabelSelector(V1LabelSelector labelSelector);
    public Boolean hasLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> withNewLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> withNewLabelSelectorLike(V1LabelSelector item);
    public V1PodAffinityTermFluent.LabelSelectorNested<A> editLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> editOrNewLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(V1LabelSelector item);
    public A addToNamespaces(int index,String item);
    public A setToNamespaces(int index,String item);
    public A addToNamespaces(String... items);
    public A addAllToNamespaces(Collection<String> items);
    public A removeFromNamespaces(String... items);
    public A removeAllFromNamespaces(Collection<String> items);
    public List<String> getNamespaces();
    public String getNamespace(int index);
    public String getFirstNamespace();
    public String getLastNamespace();
    public String getMatchingNamespace(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withNamespaces(List<String> namespaces);
    public A withNamespaces(String... namespaces);
    public Boolean hasNamespaces();
    public String getTopologyKey();
    public A withTopologyKey(String topologyKey);
    public Boolean hasTopologyKey();

    public interface LabelSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1PodAffinityTermFluent.LabelSelectorNested<N>>{

        
    public N and();    public N endLabelSelector();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1PodAffinityTermFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1PodAffinityTermFluent<A extends V1PodAffinityTermFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildLabelSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getLabelSelector();
    public V1LabelSelector buildLabelSelector();
    public A withLabelSelector(V1LabelSelector labelSelector);
    public Boolean hasLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> withNewLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> withNewLabelSelectorLike(V1LabelSelector item);
    public V1PodAffinityTermFluent.LabelSelectorNested<A> editLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> editOrNewLabelSelector();
    public V1PodAffinityTermFluent.LabelSelectorNested<A> editOrNewLabelSelectorLike(V1LabelSelector item);
    public A addToNamespaces(int index,String item);
    public A setToNamespaces(int index,String item);
    public A addToNamespaces(String... items);
    public A addAllToNamespaces(Collection<String> items);
    public A removeFromNamespaces(String... items);
    public A removeAllFromNamespaces(Collection<String> items);
    public List<String> getNamespaces();
    public String getNamespace(int index);
    public String getFirstNamespace();
    public String getLastNamespace();
    public String getMatchingNamespace(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingNamespace(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withNamespaces(List<String> namespaces);
    public A withNamespaces(String... namespaces);
    public Boolean hasNamespaces();
    public A addNewNamespace(String arg1);
    public A addNewNamespace(StringBuilder arg1);
    public A addNewNamespace(StringBuffer arg1);
    public String getTopologyKey();
    public A withTopologyKey(String topologyKey);
    public Boolean hasTopologyKey();
    public A withNewTopologyKey(String arg1);
    public A withNewTopologyKey(StringBuilder arg1);
    public A withNewTopologyKey(StringBuffer arg1);

    public interface LabelSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1PodAffinityTermFluent.LabelSelectorNested<N>>{

        
    public N and();    public N endLabelSelector();
}


}
